@@ -96,6 +96,26 @@ class ContainsMatcher(FluentMatcher):
         return self._matcher_string(text)
 
 
+class ListContainsMatcher(FluentMatcher):
+
+    def __init__(self, element):
+        self._element = element
+
+    def matches(self, value):
+        if not isinstance(value, list):
+            type_name = type(value).__name__
+            raise MatcherException('Value is of type "%s".' % type_name)
+
+        if self._element not in value:
+            return False
+        return True
+
+    def __repr__(self):
+        string_representation = repr(self._element)
+        text = 'a list containing element {element}'.format(element=string_representation)
+        return self._matcher_string(text)
+
+
 class NeverMatcher(FluentMatcher):
 
     def matches(self, value):
@@ -138,8 +158,8 @@ class TimesMatcher(FluentMatcher):
         return self._matcher_string(text)
 
 
-def contains(substring):
-    return ContainsMatcher(substring)
+def a_list_containing(element):
+    return ListContainsMatcher(element)
 
 
 def any_value_of_type(the_type):
@@ -148,3 +168,7 @@ def any_value_of_type(the_type):
 
 def any_of(*list_elements):
     return AnyOfMatcher(*list_elements)
+
+
+def contains(substring):
+    return ContainsMatcher(substring)
